Class: Aws::Braket::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Braket::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-braket/client.rb,
sig/client.rbs
Overview
An API client for Braket. To construct a client, you need to configure a :region and :credentials.
client = Aws::Braket::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelJobResponseSuccess, _CancelQuantumTaskResponseSuccess, _CreateJobResponseSuccess, _CreateQuantumTaskResponseSuccess, _CreateSpendingLimitResponseSuccess, _DeleteSpendingLimitResponseSuccess, _GetDeviceResponseSuccess, _GetJobResponseSuccess, _GetQuantumTaskResponseSuccess, _ListTagsForResourceResponseSuccess, _SearchDevicesResponseSuccess, _SearchJobsResponseSuccess, _SearchQuantumTasksResponseSuccess, _SearchSpendingLimitsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateSpendingLimitResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_job(params = {}) ⇒ Types::CancelJobResponse
Cancels an Amazon Braket hybrid job.
-
#cancel_quantum_task(params = {}) ⇒ Types::CancelQuantumTaskResponse
Cancels the specified task.
-
#create_job(params = {}) ⇒ Types::CreateJobResponse
Creates an Amazon Braket hybrid job.
-
#create_quantum_task(params = {}) ⇒ Types::CreateQuantumTaskResponse
Creates a quantum task.
-
#create_spending_limit(params = {}) ⇒ Types::CreateSpendingLimitResponse
Creates a spending limit for a specified quantum device.
-
#delete_spending_limit(params = {}) ⇒ Struct
Deletes an existing spending limit.
-
#get_device(params = {}) ⇒ Types::GetDeviceResponse
Retrieves the devices available in Amazon Braket.
-
#get_job(params = {}) ⇒ Types::GetJobResponse
Retrieves the specified Amazon Braket hybrid job.
-
#get_quantum_task(params = {}) ⇒ Types::GetQuantumTaskResponse
Retrieves the specified quantum task.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Shows the tags associated with this resource.
-
#search_devices(params = {}) ⇒ Types::SearchDevicesResponse
Searches for devices using the specified filters.
-
#search_jobs(params = {}) ⇒ Types::SearchJobsResponse
Searches for Amazon Braket hybrid jobs that match the specified filter values.
-
#search_quantum_tasks(params = {}) ⇒ Types::SearchQuantumTasksResponse
Searches for tasks that match the specified filter values.
-
#search_spending_limits(params = {}) ⇒ Types::SearchSpendingLimitsResponse
Searches and lists spending limits based on specified filters.
-
#tag_resource(params = {}) ⇒ Struct
Add a tag to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Remove tags from a resource.
-
#update_spending_limit(params = {}) ⇒ Struct
Updates an existing spending limit.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-braket/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1479 1480 1481 |
# File 'lib/aws-sdk-braket/client.rb', line 1479 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1482 1483 1484 |
# File 'lib/aws-sdk-braket/client.rb', line 1482 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 |
# File 'lib/aws-sdk-braket/client.rb', line 1452 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Braket') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-braket' context[:gem_version] = '1.74.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_job(params = {}) ⇒ Types::CancelJobResponse
Cancels an Amazon Braket hybrid job.
87 |
# File 'sig/client.rbs', line 87
def cancel_job: (
|
#cancel_quantum_task(params = {}) ⇒ Types::CancelQuantumTaskResponse
Cancels the specified task.
98 |
# File 'sig/client.rbs', line 98
def cancel_quantum_task: (
|
#create_job(params = {}) ⇒ Types::CreateJobResponse
Creates an Amazon Braket hybrid job.
109 |
# File 'sig/client.rbs', line 109
def create_job: (
|
#create_quantum_task(params = {}) ⇒ Types::CreateQuantumTaskResponse
Creates a quantum task.
169 |
# File 'sig/client.rbs', line 169
def create_quantum_task: (
|
#create_spending_limit(params = {}) ⇒ Types::CreateSpendingLimitResponse
Creates a spending limit for a specified quantum device. Spending limits help you control costs by setting maximum amounts that can be spent on quantum computing tasks within a specified time period. Simulators do not support spending limits.
196 |
# File 'sig/client.rbs', line 196
def create_spending_limit: (
|
#delete_spending_limit(params = {}) ⇒ Struct
Deletes an existing spending limit. This operation permanently removes the spending limit and cannot be undone. After deletion, the associated device becomes unrestricted for spending.
212 |
# File 'sig/client.rbs', line 212
def delete_spending_limit: (
|
#get_device(params = {}) ⇒ Types::GetDeviceResponse
Retrieves the devices available in Amazon Braket.
228 |
# File 'sig/client.rbs', line 228
def get_device: (
|
#get_job(params = {}) ⇒ Types::GetJobResponse
Retrieves the specified Amazon Braket hybrid job.
258 |
# File 'sig/client.rbs', line 258
def get_job: (
|
#get_quantum_task(params = {}) ⇒ Types::GetQuantumTaskResponse
Retrieves the specified quantum task.
285 |
# File 'sig/client.rbs', line 285
def get_quantum_task: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Shows the tags associated with this resource.
296 |
# File 'sig/client.rbs', line 296
def list_tags_for_resource: (
|
#search_devices(params = {}) ⇒ Types::SearchDevicesResponse
Searches for devices using the specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
307 |
# File 'sig/client.rbs', line 307
def search_devices: (
|
#search_jobs(params = {}) ⇒ Types::SearchJobsResponse
Searches for Amazon Braket hybrid jobs that match the specified filter values.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
325 |
# File 'sig/client.rbs', line 325
def search_jobs: (
|
#search_quantum_tasks(params = {}) ⇒ Types::SearchQuantumTasksResponse
Searches for tasks that match the specified filter values.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
344 |
# File 'sig/client.rbs', line 344
def search_quantum_tasks: (
|
#search_spending_limits(params = {}) ⇒ Types::SearchSpendingLimitsResponse
Searches and lists spending limits based on specified filters. This operation supports pagination and allows filtering by various criteria to find specific spending limits. We recommend using pagination to ensure that the operation returns quickly and successfully.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
363 |
# File 'sig/client.rbs', line 363
def search_spending_limits: (
|
#tag_resource(params = {}) ⇒ Struct
Add a tag to the specified resource.
380 |
# File 'sig/client.rbs', line 380
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Remove tags from a resource.
390 |
# File 'sig/client.rbs', line 390
def untag_resource: (
|
#update_spending_limit(params = {}) ⇒ Struct
Updates an existing spending limit. You can modify the spending amount or time period. Changes take effect immediately.
400 |
# File 'sig/client.rbs', line 400
def update_spending_limit: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1472 1473 1474 |
# File 'lib/aws-sdk-braket/client.rb', line 1472 def waiter_names [] end |