Class: Aws::Braket::Types::QuantumTaskSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-braket/types.rb

Overview

Includes information about a quantum task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_at ⇒ Time

The time at which the quantum task was created.

Returns:

  • (Time)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#device_arn ⇒ String

The ARN of the device the quantum task ran on.

Returns:

  • (String)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#ended_at ⇒ Time

The time at which the quantum task finished.

Returns:

  • (Time)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_s3_bucket ⇒ String

The S3 bucket where the quantum task result file is stored.

Returns:

  • (String)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#output_s3_directory ⇒ String

The folder in the S3 bucket where the quantum task result file is stored.

Returns:

  • (String)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#quantum_task_arn ⇒ String

The ARN of the quantum task.

Returns:

  • (String)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#shots ⇒ Integer

The shots used for the quantum task.

Returns:

  • (Integer)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the quantum task.

Returns:

  • (String)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Displays the key, value pairs of tags associated with this quantum task.

Returns:

  • (Hash<String,String>)


1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
1275
1276
1277
# File 'lib/aws-sdk-braket/types.rb', line 1265

class QuantumTaskSummary < Struct.new(
  :quantum_task_arn,
  :status,
  :device_arn,
  :shots,
  :output_s3_bucket,
  :output_s3_directory,
  :created_at,
  :ended_at,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end